#ifndef XMLPARSER_H
#define XMLPARSER_H

#include "Tools.h"
#include "XMLElements.h"

//----------------------------------------------------------------------------
class XMLParser
{
  public:
    //------------------------------------------------------------------------
    XMLParser();
    ~XMLParser();

    //------------------------------------------------------------------------
    XMLNode *parse(const char *file);
    void parse(const char *file, XMLNode &root);

    //------------------------------------------------------------------------
    DECLARE_PIMPL;
};

#endif //XMLPARSER_H
